/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
**/
#ifndef FDK_NOTIFICATION_H
#define FDK_NOTIFICATION_H

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <time.h>

typedef unsigned int uint;

// 消息弹窗跳转按钮结构体
typedef struct _fdk_notification_action {
    unsigned char *app_name;  // 点击按钮跳转到应用的名称
    unsigned char *text;      // 按钮显示的文字
} FDKNotificationAction;

// 消息弹窗信息结构体
typedef struct _fdk_notification_info {
    unsigned int id;                      // 消息通知ID
    unsigned char *name;                  // 消息弹窗名称
    unsigned char *msg;                   // 消息弹窗内容
    unsigned char *title;                 // 消息弹窗标题
    unsigned char *icon;                  // 消息弹窗图标
    time_t timestamp;                     // 消息通知发送的时间
    FDKNotificationAction action[3];      // 消息弹窗跳转按钮，最多可以添加三个
    int milliseconds;                     // 设置消息弹窗的显示时长，-1为系统默认时长，0为常驻消息
} FDKNotificationInfo;

// 通知模式类型枚举
enum FDKNotificationMode {
    NOTIFICATION_MODE_OFF = 0,            // 关闭勿扰模式
    NOTIFICATION_MODE_ON = 1,             // 启用勿扰模式
    NOTIFICATION_MODE_INVALID = -1        // 获取失败或模式无效
};

// 通知优先级类型枚举
enum FDKNotificationPriority {
    NOTIFICATION_PRIORITY_LOW = 0,
    NOTIFICATION_PRIORITY_NORMAL = 1,
    NOTIFICATION_PRIORITY_HIGH = 2
};

/**
 * 初始化消息通知。
 *
 * @return 成功返回通知ID，失败返回错误码。
 */
uint fdk_notification_init(void);

/**
 * 发送消息通知请求。
 *
 * @param[in] id 消息通知的ID。
 * @return 成功返回通知ID，失败返回错误码。
 */
int fdk_notification_send(uint id);

/**
 * 清除所有的通知。
 *
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_clear(void);

/**
 * 列出所有的通知。
 *
 * @param[out] notifications 指向所有通知的列表，需调用fdk_notification_free释放空间。
 * @param[out] cnt 所有通知的数量。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_list(FDKNotificationInfo **notifications, int *cnt);

/**
 * 释放fdk_notification_list申请的空间。
 *
 * @param[in,out] notifications 指向所有通知的列表。
 * @param[in] cnt 所有通知的数量。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_free(FDKNotificationInfo **notifications, int cnt);

/**
 * 设置默认跳转到指定应用。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] app_name 跳转到指定应用的路径。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_redirect(int id, char* app_name);

/**
 * 设置消息弹窗中添加跳转按钮。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] action 跳转按钮信息。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_action(int id, FDKNotificationAction *action);

/**
 * 设置消息弹窗的显示时长。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] duration 消息弹窗的显示时长，-1为系统默认时长，0为常驻消息。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_duration(int id, int duration);

/**
 * 设置消息弹窗应用名称。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] name 消息弹窗应用名称。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_appname(int id, char *name);

/**
 * 设置消息弹窗主内容。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] msg 消息弹窗主内容。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_msg(int id, char *msg);

/**
 * 设置消息弹窗标题。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] title 消息弹窗标题。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_title(int id, char *title);

/**
 * 设置消息弹窗应用图标。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] icon 消息弹窗应用图标。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_icon(int id, char *icon);

/**
 * 设置通知优先级。
 *
 * @param[in] id 消息通知的ID。
 * @param[in] priority 消息弹窗的优先级。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_priority(int id, int priority);

/**
 * 设置全局通知模式。
 *
 * @param[in] mode 全局通知模式（NOTIFICATION_MODE_OFF 或 NOTIFICATION_MODE_ON）。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_set_global_mode(enum FDKNotificationMode mode);

/**
 * 获取全局通知模式。
 *
 * @return 当前全局通知模式（NOTIFICATION_MODE_OFF 或 NOTIFICATION_MODE_ON）。
 *         如果获取失败，返回 NOTIFICATION_MODE_INVALID。
 */
enum FDKNotificationMode fdk_notification_get_global_mode(void);

/**
 * 设置指定应用的通知模式。
 *
 * @param[in] app_name 应用名称。
 * @param[in] mode 通知模式（NOTIFICATION_MODE_OFF 或 NOTIFICATION_MODE_ON）。
 * @return 成功返回0，失败返回错误码。
 * 
 * 待实现
 */
int fdk_notification_set_app_mode(const unsigned char *app_name, enum FDKNotificationMode mode);

/**
 * 关闭消息弹窗。
 *
 * @param[in] id 消息弹窗的ID。
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_close(int id);

/**
 * 释放消息通知系统初始化时分配的所有资源。
 *
 * @return 成功返回0，失败返回错误码。
 */
int fdk_notification_uninit(void);

#ifdef __cplusplus
}
#endif

#endif // FDK_NOTIFICATION_H