/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
**/
#ifndef FDK_TASKPANEL_H
#define FDK_TASKPANEL_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 任务栏管控模式
 */
typedef enum {
    TASKBAR_CONTROL_MODE_NORMAL,       /**< 正常模式 */
    TASKBAR_CONTROL_MODE_BLACK,        /**< 黑名单模式 */
    TASKBAR_CONTROL_MODE_WHITE         /**< 白名单模式 */
} FDKTaskbarControlMode;


/**
 * @brief 任务栏位置的枚举定义,用于指定任务栏的显示位置。
 */
typedef enum {
    PANEL_POSITION_TOP,               /**< 面板位于屏幕顶部 */
    PANEL_POSITION_BOTTOM,            /**< 面板位于屏幕底部 */
    PANEL_POSITION_LEFT,              /**< 面板位于屏幕左侧 */
    PANEL_POSITION_RIGHT              /**< 面板位于屏幕右侧 */
} FDKPanelPosition;


/**
 * @brief 任务栏自动隐藏状态的枚举定义,用于指定任务栏是否自动隐藏。
 */
typedef enum {
    PANEL_AUTOHIDE_DISABLE,     /**< 禁用自动隐藏任务栏 */
    PANEL_AUTOHIDE_ENABLE       /**< 启用自动隐藏任务栏 */
} FDKPanelAutoHideStatus;


/**
 * @brief 设置任务栏管控模式
 * @param mode 任务栏的控制模式
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_set_control_mode(int mode);


/**
 * @brief 获取任务栏管控模式
 * @return 成功返回任务栏的控制模式，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_get_control_mode();


/**
 * @brief 添加应用到任务栏管控黑名单
 * @param appname 应用名
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_add_app_to_blacklist(char * appname);


/**
 * @brief 从任务栏管控黑名单删除管控应用
 * @param appname 应用名
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_remove_app_from_blacklist(char * appname);


/**
 * @brief 清空任务栏管控黑名单
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_clear_blacklist(void);


/**
 * @brief 添加应用到任务栏管控白名单
 * @param appname 应用名
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_add_app_to_whitelist(char * appname);


/**
 * @brief 从任务栏管控白名单删除管控应用
 * @param appname 应用名
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_remove_app_from_whitelist(char * appname);


/**
 * @brief 清空任务栏白名单
 * @return 成功返回0，失败返回错误码
 * @note 该函数暂不支持。
 */
int fdk_taskbar_clear_whitelist(void);


/**
 * @brief 显示任务栏
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_show(void);


/**
 * @brief 隐藏任务栏
 * @return 成功返回0，失败返回错误码
  */
int fdk_taskbar_hide(void);


/**
 * @brief 激活任务栏按钮对应的应用程序
 * @param app_name 应用程序的名字 或 id
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_app_active(const char *app_name);


/**
 * @brief 设置任务栏位置
 * @param position 任务栏位置，使用 `FDKPanelPosition` 枚举值来指定任务栏的位置
 * @return 成功返回0，失败返回错误码
 */
int  fdk_taskbar_set_position(int position);


/**
 * @brief 获取任务栏的位置
 * @return 当前任务栏的位置，使用 `FDKPanelPosition` 枚举值，失败时返回负数错误码
 */
int  fdk_taskbar_get_position(void);


/**
 * @brief 设置任务栏自动隐藏
 * @param status 任务栏自动隐藏状态，使用 `FDKPanelAutoHideStatus` 枚举值来指定
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_autohide(int status);


/**
 * @brief 获取任务栏自动隐藏状态
 * @return 当前任务栏的自动隐藏状态，使用 `FDKPanelAutoHideStatus` 枚举值，失败时返回负数错误码
 */
int fdk_taskbar_get_status(void);


/**
 * @brief 设置任务栏高度
 * @param height 任务栏高度，单位为像素（px）
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_set_height(int height);


/**
 * @brief 获取当前任务栏的高度
 * @return 当前任务栏的高度（单位：像素），失败时返回负数表示错误
 */
int fdk_taskbar_get_height(void);


/**
 * @brief 打开开始菜单
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_menu(void);


/**
 * @brief 关闭开始菜单
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_menu(void);


/**
 * @brief 打开工作区视图
 * @return 成功返回0，失败返回错误码
 */
int  fdk_taskbar_open_workspace(void);


/**
 * @brief 关闭工作区视图
 * @return 成功返回0，失败返回错误码
 */
int  fdk_taskbar_close_workspace(void);


/**
 * @brief 打开通知中心
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_notification_center(void);


/**
 * @brief 关闭通知中心
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_notification_center(void);


/**
 * @brief 打开日历
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_calendar(void);


/**
 * @brief 关闭日历
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_calendar(void);


/**
 * @brief 打开可移动设备窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_removable_devices(void);


/**
 * @brief 关闭可移动设备窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_removable_devices(void);


/**
 * @brief 打开网络窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_network_settings(void);


/**
 * @brief 关闭网络窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_network_settings(void);


/**
 * @brief 打开声音设置窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_sound_settings(void);


/**
 * @brief 关闭声音设置窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_sound_settings(void);


/**
 * @brief 打开任务栏的“显示桌面”状态
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_show_desktop(void);

/**
 * @brief 关闭任务栏的“显示桌面”状态
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_desktop(void);

/**
 * @brief 打开任务栏的“电源”视图
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_power(void);

/**
 * @brief 关闭任务栏的“电源”视图
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_power(void);


/**
 * @brief 打开任务窗口切换器视图
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_open_task_switcher(void);


/**
 * @brief 关闭任务窗口切换器视图
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_close_task_switcher(void);


/**
 * @brief 切换到下一个任务窗口
 * @return 成功返回0，失败返回错误码
 */
int fdk_taskbar_switch_next_task(void);


/**
 * @brief 切换到下一个显示模式
 * @return 成功返回0，失败返回错误码
 * @note 确保系统已支持多个显示模式，并且能够顺利切换。
 * 此接口会依次切换到系统支持的下一个显示模式，当切换到最后一个模式时，
 * 重新从第一个模式开始切换。
 */
int fdk_taskbar_switch_next_display_mode(void);


#ifdef __cplusplus
}
#endif

#endif // FDK_TASKPANEL_H